@@ -12,6 +12,7 @@ def immutable(self, *_args, **_kwargs):
 
 
 _empty_frozendict = None
+_module_name = "frozendict"
 
 
 # noinspection PyPep8Naming
@@ -22,7 +23,7 @@ class frozendict(dict):
     The API is the same as `dict`, without methods that can change the
     immutability. In addition, it supports __hash__().
     """
-    
+            
     __slots__ = (
         "_hash",
     )
@@ -104,7 +105,7 @@ class frozendict(dict):
         klass = self.__class__
         
         if klass == frozendict:
-            name = f"frozendict.{klass.__name__}"
+            name = f"{_module_name}.{klass.__name__}"
         else:
             name = klass.__name__
         
@@ -159,7 +160,7 @@ class frozendict(dict):
         return (self.__class__, (dict(self),))
     
     def set(self, key, val):
-        new_self = deepcopy(dict(self))
+        new_self = dict(self)
         new_self[key] = val
         
         return self.__class__(new_self)
@@ -168,14 +169,14 @@ class frozendict(dict):
         if key in self:
             return self
         
-        new_self = deepcopy(dict(self))
+        new_self = dict(self)
         
         new_self[key] = default
         
         return self.__class__(new_self)
     
     def delete(self, key):
-        new_self = deepcopy(dict(self))
+        new_self = dict(self)
         del new_self[key]
         
         if new_self:
@@ -235,7 +236,7 @@ frozendict.__ior__ = frozendict_or
 try:
     # noinspection PyStatementEffect
     frozendict.__reversed__
-except AttributeError:
+except AttributeError:  # pragma: no cover
     def frozendict_reversed(self, *_args, **_kwargs):
         return reversed(tuple(self))
     
@@ -248,6 +249,6 @@ frozendict.popitem = immutable
 frozendict.update = immutable
 frozendict.__delattr__ = immutable
 frozendict.__setattr__ = immutable
-frozendict.__module__ = 'frozendict'
+frozendict.__module__ = _module_name
 
 __all__ = (frozendict.__name__,)
